Author: Ed Grossman
Description: The official web site of the Vermont Judicial System, with on-line Vermont Court forms and Vermont Legal Resources.
Keywords: Vermont Judicial System, Vermont Court Forms, Vermont Legal Resources, Vermont Supreme Court, State Court, Court

| Turn on more accessible mode Skip to main content
Turn off more accessible mode # Legal Community

##
| ### Quick Launch View All Site Content
Legal Information
Administrative Order No. 9
Annual Reports of the PRB
Attorney Discipline Information
Attorney Licensing (Including Pro Hac Vice)
Bar Admissions
Complaint Brochure
Civil Division Opinions
Environmental Division Opinions
Judicial Conduct Board
Legal Links (Including Statutes and Rules)
Mandatory Continuing Legal Education
Memos to the Bar
Policies
Preliminary Evaluators
Proposed and Promulgated Rules
Professional Responsibility Board Decisions
Supreme Court Decisions
Supreme Court Oral Arguments
Trust Account Manual
VT Rules of Professional Conduct
Vermont Supreme Court Unpublished Entry Orders 2011 - Present
Case Name | Filed | Unit/Division | Trial Judge | Disposition
--- | --- | --- | --- | ---
Year of Decision: 2015
Month of Decision: 01 | January
Nadihusska Leon v. Eugenio Leon | 1/9/2015 | Lamoille Unit, Family Division | Robert R. Bent | Affirmed.
State v. Miguel Francisco | 1/9/2015 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
In re Donald R. O'Dell, Jr. | 1/9/2015 | Bennington Unit, Civil Division | John P. Wesley | Affirmed.
In re Darrell Day | 1/9/2015 | Bennington Unit, Civil Division | John P. Wesley | Affirmed.
State v. Kyle Doyle | 1/9/2015 | Windsor Unit, Criminal Division | Karen R. Carroll | Affirmed.
Peggy List v. Paul List | 1/9/2015 | Chittenden Unit, Family Division | Linda Levitt | Reversed and remanded on reasonableness of attorney's fees for the enforcement motion and ability to pay them. Affirmed in all other respects.
Michael Rinaldo v. Green Mountain Self Storage and Jim O'Dell | 1/9/2015 | Bennington Unit, Civil Division | John P. Wesley | Affirmed as to defendant Green Mountain Self Storage; reversed and remanded as to defendant Jim O'Dell.
J. Herbert Dahm, Jr. and Arlene L. Dahm v. Town of Charleston | 1/9/2015 | Orleans Unit, Civil Division | A. Gregory Rainville | Affirmed.
In re D.C. | 1/9/2015 | Windham Unit, Criminal Division | John P. Wesley/Brian J. Grearson | Affirmed.
David Finlayson v. Linda Finlayson | 1/9/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
State v. Bruce Bona | 1/9/2015 | Chittenden Unit, Criminal Division | Robert R. Bent | Affirmed.
Tracey Bushey v. William Bushey | 1/9/2015 | Chittenden Unit, Family Division | Linda Levitt | Reveresed and remanded.
In re S.G., Juvenile | 1/9/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
In re J.D., Juvenile | 1/9/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
In re G.W., Juvenile | 1/9/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
State v. Chad Morris | 1/2/2015 | Rutland Unit, Criminal Division | Thomas A. Zonay | Affirmed.
Month of Decision: 02 | February
Jennifer Doyle v. Joseph Lourenco, Jr. | 2/6/2015 | Caledonia Unit, Family Division | M. Kathleen Manley | Affirmed.
State v. Michael Hughes | 2/6/2015 | Bennington Unit, Criminal Division | Nancy Corsones | Affirmed.
Michael Hanson-Metayer v. Elizabeth Hanson-Metayer | 2/6/2015 | Chittenden Unit, Family Division | A. Gregory Rainville | Affirmed.
State v. Robert Mongeon | 2/6/2015 | Chittenden Unit, Criminal Division | Samuel Hoar, Jr. | Affirmed.
In re B.K., Juvenile | 2/6/2015 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
In re T.M., Juvenile | 2/6/2015 | Lamoille Unit, Family Division | Timothy B. Tomasi | Affirmed.
State v. James King | 2/6/2015 | Chittenden Unit, Criminal Division | Michael S. Kupersmith/Brian J. Grearson | Affirmed.
Town of Colchester v. Robert Andres | 2/6/2015 | Environmental Division | Thomas S. Durkin | Affirmed.
In re A.N., Juvenile | 2/6/2015 | Rutland Unit, Family Division | Howard A. Kalfus, Acting Judge | Affirmed.
Susan Moraska v. Albert Moraska | 2/6/2015 | Chittenden Unit, Civil Division | Dennis R. Pearson | Affirmed.
In re A.H., Juvenile | 2/6/2015 | Windsor Unit, Family Division | Harold E. Eaton, Jr. | Affirmed.
Mark Macha v. Andrew Pallito, Commissioner | 2/6/2015 | Orleans Unit, Civil Division | A. Gregory Rainville | Affirmed.
Month of Decision: 03 | March
State v. Joshua Hayes | 3/6/2015 | Bennington Unit, Criminal Division | Cortland Corsones | Affirmed.
State v. Thomas Tatro | 3/6/2015 | Addison Unit, Criminal Division | Robert A. Mello | Affirmed.
State v. John Haskins | 3/6/2015 | Bennington Unit, Criminal Division | Nancy Corsones | Affirmed.
State v. Harvey Epps | 3/6/2015 | Washington Unit, Criminal Division | Thomas A. Zonay | Affirmed.
Colby Cheever v. Crystal Merrick | 3/6/2015 | Addison Unit, Family Division | Linda Levitt | Affirmed.
State v. Mark Snow | 3/6/2015 | Addison Unit, Criminal Division | Robert A. Mello | Reversed and remanded.
In re L.W. and J.W., Juveniles | 3/6/2015 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
George Kingston III v. Montpelier Public School System | 3/6/2015 | Washington Unit, Civil Division | Helen M. Toor | Affirmed.
Donald Bishop v. Town of Springfield | 3/10/2015 | Windsor Unit, Civil Division | Mary Miles Teachout | Affirmed.
Ricky Curtis, Jr. v. Andrew Pallito, Commissioner of Dept. of Corrections, Robert Berthiaume and Scott Morley | 3/17/2015 | Orange Unit, Civil Division | Howard E. Van Benthuysen | Affirmed.
Month of Decision: 04 | April
Omar Rodriguez v. Philisha Rodriguez | 4/10/2015 | Caledonia Unit, Family Division | Robert R. Bent | Affirmed.
Kayla Eaton v. Leroy Prior, Prior Polygraph, Matthew Bellmay and Vermont State Police | 4/10/2015 | Washington Unit, Civil Division | Robert R. Bent | Affirmed.
Nicole Little v. Kym Blaisdell | 4/10/2015 | Orange Unit, Family Division | Robert P. Gerety, Jr. | Affirmed.
In re Estate of Herman Venheim | 4/10/2015 | Essex Unit, Civil Division | Robert R. Bent | Affirmed.
Kristin Brosnahan v. William Brosnahan | 4/10/2015 | Orange Unit, Family Division | Robert P. Gerety, Jr. | Affirmed.
May Chiles (May Mantell) v. John Vaughan Chiles | 4/10/2015 | Addison Unit, Family Division | Linda Levitt | Affirmed.
In re D.M., Juvenile | 4/10/2015 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
Prentice Weitman v. Johanna Staudinger Weitman | 4/10/2015 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
In re R.A., Juvenile | 4/10/2015 | Orleans Unit, Family Division | M. Kathleen Manley | Affirmed.
David Smalley v. Stowe Mountain Club, LLC | 4/10/2015 | Lamoille Unit, Civil Division | Helen M. Toor | Affirmed.
In re N.R. and L.B., Juveniles | 4/10/2015 | Windsor Unit, Family Division | Harold E. Eaton, Jr. | Affirmed.
In re M.S., Juvenile | 4/10/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
In re B.H. and A.H.B., Juveniles | 4/10/2015 | Chittenden Unit, Family Division | James R. Crucitti | Affirmed.
In re D.G. and D.G., Juveniles | 4/10/2015 | Chittenden Unit, Family Division | Thomas J. Devine | Affirmed.
In re M.H. and B.H., Juveniles | 4/10/2015 | Bennington Unit, Family Division | William D. Cohen | Affirmed.
In re K.B., Juvenile | 4/10/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
State v. Carroll Sparks, Jr. | 4/22/2015 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
Month of Decision: 05 | May
State v. Scott Manfredi | 5/14/2015 | Rutland Unit, Criminal Division | Theresa S. DiMauro | Affirmed.
State v. Ralph N. Morale | 5/14/2015 | Caledonia Unit, Criminal Division | Robert R. Bent | Reversed and remanded for reconsideration.
State v. Laura Rudd | 5/14/2015 | Bennington Unit, Criminal Division | Nancy Corsones | Affirmed.
Pieter Heydenrych v. Nicole Heydenrych | 5/14/2015 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
Charles Chandler v. State | 5/14/2015 | Windham Unit, Civil Division | Mary Miles Teachout | Affirmed.
Tammy Schey v. Daniel Fuller | 5/14/2015 | Chittenden Unit, Civil Division | Michael S. Kupersmith | Reversed and remanded for the superior court to deduct $11,437 from defendant's house-related contributions, to make a new accounting award based on that change, and to enter a new judgment.
In re Town Highway 26, Town of Underhill | 5/14/2015 | Chittenden Unit, Civil Division | Dennis R. Pearson | Affirmed.
Charles Chandler v. Town of Newfane and Doris Knechtel, Individually and as Employee of Town of Newfane | 5/14/2015 | Windham Unit, Civil Division | Mary Miles Teachout | Affirmed.
Adam George (Office of Child Support) v. Bahji Adams | 5/14/2015 | Chittenden Unit, Family Division | Martin A. Maley | Affirmed.
In re K.S., Juvenile | 5/14/2015 | Bennington Unit, Family Division | David A. Howard | Affirmed.
Nina Darling v. Theodore Crow | 5/14/2015 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
Timothy S. Johnson v. Green Mountain Power Corportion | 5/14/2015 | Windham Unit, Civil Division | Theresa S. DiMauro | Affirmed.
State v. Hillary Lumbra | 5/14/2015 | Caledonia Unit, Criminal Division | Robert R. Bent | Affirmed.
Albert Alpine Bingham v. Town of Middlebury | 5/14/2015 | Addison Unit, Civil Division | Robert A. Mello | Affirmed.
Alice Ann O'Brien v. William Henkel | 5/14/2015 | Bennington Unit, Family Division | William D. Cohen | Affirmed.
In re C.M., Juvenile | 5/14/2015 | Orange Unit, Family Division | Howard A. Kalfus, Specially Assigned | Affirmed.
In re J.T. and A.T., Juveniles | 5/14/2015 | Franklin Unit, Family Division | Howard A. Kalfus, Specially Assigned | Affirmed.
State v. Christopher P. Sullivan | 5/8/2015 | Rutland Unit, Criminal Division | Theresa S. DiMauro | Reversed and remanded with instructions to amend the conditions-of-release order to allow defendant to post bail by executing a secured apperance bond. Affirmed in all other respects.
Month of Decision: 06 | June
State v. Julio Davila | 6/12/2015 | Windham Unit, Criminal Division | Dsvid Suntag | Affirmed.
State v. Frank Highley | 6/12/2015 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
Robert Magee v. Dept. of Labor (Chittenden East Supervisory Union, Employer) | 6/12/2015 | Employment Security Board | n/a | Affirmed.
State v. George Mannoia | 6/12/2015 | Bennington Unit, Criminal Division | Nancy Corsones | Affirmed.
State v. Matthew Fay | 6/12/2015 | Chittenden Unit, Criminal Division | Samuel Hoar, Jr. | Affirmed.
In re Marvin Waldman | 6/12/2015 | Human Services Board | n/a | Affirmed
State v. Mariusz Curylo | 6/12/2015 | Bennington Unit, Criminal Division | William D. Cohen | Affirmed.
Megan Boyle v. Kevin O'Neill | 6/12/2015 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
Jennifer Johnson v. Gregory Johnson | 6/12/2015 | Chittenden Unit, Family Division | Samuel Hoar, Jr. | Affirmed.
Jill Rinehart, M.D. v. Eroc Svensson | 6/12/2015 | Chittenden Unit, Family Division | Samuel Hoar, Jr. | Affirmed in part, remanded in part.
In re Zaremba Group Dollar General CU Permit | 6/12/2015 | Environmental Division | Thomas G. Walsh | Affirmed.
In re L.W., D.M.S., R.S. & A.S., Juveniles | 6/12/2015 | Caledonia Unit, Family Division | Howard A. Kalfus, Acting Superior Court Judge | Affirmed.
Adam Hubacz v. The Village of Waterbury, Vermont and William Shepeluk | 6/12/2015 | Washington Unit, Civil Division | Mary Miles Teachout | Affirmed.
Victor Hall v. Michael Vinton | 6/12/2015 | Chittenden Unit, Civil Division | Helen M. Toor | Affirmed.
Brian Farr-Maccione v. Dept. of Labor | 6/12/2015 | Employment Security Board | n/a | Affirmed.
Brian Farr-Maccione v. Dept. of Labor (Vermont Teddy Bear Co., Appellee) | 6/12/2015 | Employment Security Board | n/a | Affirmed.
In re D.S., Juvenile | 6/16/2015 | Caledonia Unit, Family Division | Howard A. Kalfus, Acting Superior Court Judge | Affirmed.
State v. Caitlyn Fregeau | 6/2/2015 | Franklin Unit, Criminal Division | Alison S. Arms | Affirmed.
State v. Dustin LaFountain | 6/29/2015 | Franklin Unit, Criminal Division | Alison S. Arms | Affirmed.
Month of Decision: 07 | July
State v. Christina Allcock | 7/24/2015 | Windham Unit, Criminal Division | David Suntag | Affirmed.
In re Barry Babson | 7/24/2015 | Bennington Unit, Civil Division | John P. Wesley | Affirmed.
State v. Anthony Morabito | 7/24/2015 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
State v. Brian Shannon | 7/24/2015 | Essex Unit, Criminal Division | Robert R. Bent | Affirmed.
State v. Katie Benware | 7/24/2015 | Orleans Unit, Criminal Division | Timothy B. Tomasi | Affirmed.
In re Guardianships of D.B., T.B. and B.B. | 7/24/2015 | Windsor Unit, Civil Division | Joanne M. Ertel | Affirmed.
In re Craig Yandow | 7/24/2015 | Chittenden Unit, Civil Division | Helen M. Toor | Affirmed.
In re B.H., Juvenile | 7/24/2015 | Orange Unit, Family Division | Amy M. Davenport, Specially Assigned (Ret.) | Affirmed.
State v. Spencer Durham | 7/24/2015 | Bennington Unit, Criminal Division | Cortland Corsones | Appeal dismissed.
In re C.L. and S.L., Juveniles | 7/24/2015 | Caledonia Unit, Family Division | M Kathleen Manley | Affirmed.
In re S.K. and Z.K., Juveniles | 7/24/2015 | Bennington Unit, Family Division | William D. Cohen | Remanded for further proceedings consistent with this decision.
In re B.R., Juvenile | 7/24/2015 | Franklin Unit, Family Division | Howard Kalfus, Specially Assigned | Affirmed.
In re B.S., Juvenile | 7/24/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
Bernard Carter v. Andrew Pallito, Commissioner, Dept of Corrections | 7/24/2015 | Washington Unit, Civil Division | Mary Miles Teachout | Affirmed.
In re J.P. | 7/27/2015 | Lamoille Unit, Family Division | Timothy B. Tomasi | Affirmed.
People's United Bank v. Michael Cornish | 7/24/2015 | Windham Unit, Civil Division | John P. Wesley | Appeal dismissed.
Month of Decision: 08 | August
Tammy Shaw v. Dept. of Labor | 8/12/2015 | Employment Security Board | n/a | Affirmed.
State v. Brien Daignault | 8/12/2015 | Essex Unit, Criminal Division | Robert R. Bent | Affirmed.
Bruce Willette v. Dept. of Labor (Washington County Youth Services, Inc., Employer) | 8/12/2015 | Employment Security Board | n/a | Reversed.
John Norton-Griffiths and Marilyn Norton-Griffiths v. Wells Fargo & Co., Downs, Rachlin & Martin PLLC, et al. | 8/12/2015 | Rutland Unit, Civil Division | Harold E. Eaton, Jr. (partial suammary judgement)/William D. Cohen (final judgement) | Affirmed.
Clark and Maura Pierson and James and Sarah Pierson v. M'nt Maple, LLC | 8/12/2015 | Franklin Unit, Civil Division | A. Gregory Rainville | Affirmed.
Rosemary Noel v. Andre Noel | 8/12/2015 | Washington Unit, Family Division | Thomas J. Devine | Affirmed.
Michael Cornish v. Town of Brookline | 8/12/2015 | Property Valuation and Review Division | n/a | Reversed and remanded.
Pamela Washburn v. Mark Fowlkes | 8/12/2015 | Rutland Unit, Family Division | Mary Welford, Acting Judge | Affirmed.
In re S.P., Juvenile | 8/12/2015 | Chittenden Unit, Family Division | Michael S. Kupersmith | Affirmed.
In re Anthony John Palubicki | 8/12/2015 | Orleans Unit, Civil Division | Timothy B. Tomasi | Affirmed.
Stephen and Margaret Conant v. Chris Khamnei | 8/12/2015 | Chittenden Unit, Civil Division | Dennis R. Pearosn | Affirmed.
Dylan Cady v. Andrew Pallito, Commissioner, Dept. of Corrections | 8/12/2015 | Orleans Unit, Civil Division | Timothy B. Tomasi | Reversed and remanded with instructions to grant summary judgement to plaintiff.
Month of Decision: 09 | September
In re J.P. | 9/30/2015 | Chittenden Unit, Criminal Division | Brian J. Grearson | Affirmed.
State v. Bruce Bona | 9/30/2015 | Caledonia Unit, Criminal Division | Robert R. Bent | Affirmed.
Alexander Leveille v. Gyan Baird and Gyan Baird v. Alexander Leveille | 9/30/2015 | Lamoille Unit, Family Division | Dennis R. Pearson | Affirmed.
David Massey v. Town of Greensboro | 9/30/2015 | Orleans Unit, Civil Division | A. Gregory Rainville | Affirmed.
Eugene Ladd v. Andrew Pallito, et al. | 9/30/2015 | Washington Unit, Civil Division | Mary Miles Teachout | Affirmed.
State v. Millard Waite | 9/30/2015 | Windham Unit, Criminal Division | David Suntag | Affirmed.
State v. Alec Morse | 9/30/2015 | Addison Unit, Criminal Division | Robert A. Mello | Affirmed.
Qurban Khalsa a/k/a Kieran Gallagher v, Inder Khalsa | 9/30/2015 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
Sheryl Tepper and Stephen Kesman v. Patricia Garcia | 9/30/2015 | Rutland Unit, Civil Division | Cortland Corsones | Affirmed.
In re C.A. and S.A., Juveniles | 9/30/2015 | Orleans Unit, Family Division | M. Kathleen Manley | Affirmed.
Kirk Wool v. Andrew Pallito | 9/30/2015 | Washington Unit, Civil Division | Mary Miles Teachout | Reversed and remanded.
John Rishar, Jr. v. Kinney Drugs, et al. | 9/30/2015 | Caledonia Unit, Civil Division | Robert R. Bent | Affirmed.
In re M.G., Juvenile | 9/30/2015 | Chittenden Unit, Family Division | Michael S. Kupersmith | Affirmed.
In re M.T., R.T. and D.T., Juveniles | 9/30/2015 | Franklin Unit, Family Division | Howard E. Van Benthuysen | Affirmed.
In re A.W., T.W. and D.W., Juveniles | 9/30/2015 | Bennington Unit, Family Division | William D. Cohen | Affirmed.
In re B.S., Juvenile | 9/30/2015 | Franklin Unit, Family Division | A. Gregory Rainville | Affirmed.
State v. Zachary Ware | 9/25/2015 | Bennington Unit, Criminal Division | Cortland T. Corsones, David A. Howard | Affirmed.
State v. Brian M. Barrow | 9/21/2015 | Windsor Unit, Criminal Division | Theresa S. DiMauro | Affirmed.
Year of Decision: 2014
Month of Decision: 01 | January
In re Isaac Faham | 1/23/2014 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
In re Bradford Trucking, Inc. | 1/23/2014 | Employment Security Board | n/a | Reversed and remanded.
State v. Jeffrey Powers | 1/23/2014 | Orleans Unit, Criminal Division | Howard E. Van Benthuysen | Affirmed.
Susan Meredith v. Mark Meredith | 1/23/2014 | Orleans Unit, Family Division | Howard E. Van Benthuysen | Reversed and remanded.
Joseph Hall, Mary Hall, Scott Maguire and Mary Maguire v. Christopher Denio and Holland Co., Inc. | 1/23/2014 | Bennington Unit, Civil Division | Karen R. Carroll | Affirmed.
In re UVM Certificate of Appropriateness | 1/23/2014 | Environmental Division | Thomas G. Walsh | Affirmed.
Bethany Drum v. Ricky Henry Dodge/Bethany Drum v. Leon Timothy Colbeth | 1/23/2014 | Orange Unit, Family Division | Robert P. Gerety, Jr. | Affirmed.
In re I.B., Juvenile | 1/23/2014 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
In re S.B., Juvenile | 1/23/2014 | Chittenden Unit, Family Division | Michael S. Kupersmith | Affirmed.
In re J.P., C.P., N.P. & T.W., Juveniles | 1/23/2014 | Chittenden Unit, Family Division | Kevin Griffin | Affirmed.
In re S.L., Juvenile | 1/23/2014 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
Sheila Boyer v. Armand Niquette | 1/7/2014 | Chittenden Unit, Civil Division | n/a | Dismissed.
Month of Decision: 02 | February
State v. John Kunhardt | 2/20/2014 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
State v. Zachariah McAllister | 2/20/2014 | Windham Unit, Criminal Division | David Suntag | Affirmed.
David Berrie d/b/a David Berrie Real Estate v. Robin O'Neill | 2/20/2014 | Windham Unit, Civil Division | Karen R. Carroll | Affirmed.
State v. Perry Lowell | 2/20/2014 | Orange Unit, Criminal Division | Timothy B. Tomasi | Affirmed.
In re Wallace Nolen | 2/20/2014 | Washington Unit, Civil Division | Robert R. Bent | Affirmed.
Vermont Federal Credit Union v. Drew Richter and Russell Richter | 2/20/2014 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Walsh Electric Supply, LLC v. All Seasons Excavating & Landscaping, Inc. and Robby Mazza | 2/20/2014 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
In re A.W. and A.W., Juveniles | 2/20/2014 | Orleans Unit, Family Division | M. Kathleen Manley | Affirmed.
Holly Nichols v. John Nichols | 2/20/2014 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Henry Richmond v. Sheila Richmond | 2/20/2014 | Bennington Unit, Family Division | David A. Howard | Affirmed.
Matthew Stevens v. Andrew Pallito, Tammy Osbourne, Shay Mitchell, ARNP and Derrick Hamilton, M.D. | 2/20/2014 | Washington Unit, Civil Division | Robert R. Bent | Affirmed.
Month of Decision: 03 | March
Catherine Heller v. Bast and Rood Architechts | 3/28/2014 | Commissioner of Labor | n/a | Affirmed.
In re S.C., Juvenile | 3/28/2014 | Washington Unit, Family Division | Howard A. Kalfus/Amy M. Davenport | Affirmed.
In re J.R. | 3/28/2014 | Rutland Unit, Family Division | William D. Cohen | Affirmed.
Isabella Oehry v. Christopher Mangini | 3/28/2014 | Windsor Unit, Family Division | Katherine A. Hayes | Affirmed.
Christopher Webb v. Andrew Pallito, Charles E. Samuels, Jr. and Tamyra Jarvis | 3/28/2014 | Washington Unit, Civil Division | Robert R. Bent | Reversed and remanded.
State v. Kevin Terrance Shea a/k/a Eejipp Ala | 3/28/2014 | Franklin Unit, Criminal Division | Martin A. Maley | Affirmed.
In re T.F. and B.F., Juveniles | 3/28/2014 | Caledonia Unit, Family Division | Walter M. Morris, Jr. | Affirmed.
Eejipp Ala v. Andrew Pallito, Commissioner of Dept of Corrections | 3/28/2014 | Orleans Unit, Civil Division | Howard E. Van Benthuysen | Affirmed.
In re E.C., Juvenile | 3/28/2014 | Orleans Unit, Family Division | M. Kathleen Manley | Affirmed.
State v. Derrick D. Jones | 3/14/2014 | Franklin Unit, Criminal Division | Martin A. Maley | Reversed and remanded.
In re C.L., M.L., D.L. & C.L., Juveniles | 3/28/2014 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
Month of Decision: 04 | April
State v. Ryan J. McCauley | 4/4/2014 | Bennington Unit, Criminal Division | Nancy Corsones | The court orders that defendant be released on the above-listed conditions at this time.
Judith Meyncke v. Robert Meyncke | 4/7/2014 | Chittenden Unit, Family Division | Linda Levitt | The judgment is affirmed, and the matter is remanded, to determine the final child support and spousal maintenance arrearages.
Lisa Mangini v. Richard E. Hardie | 4/25/2014 | Windsor Unit, Family Division | William D. Cohen | Reversed and remanded.
State v. Christopher Cerutti | 4/25/2014 | Washington Unit, Criminal Division | Christina C. Reiss | Affirmed.
Leroy Goodwin v. Andrew Pallito | 4/25/2014 | Windsor Unit, Civil Division | Robert P. Gerety, Jr. | Affirmed.
State v. Jess Taylor | 4/25/2014 | Addison Unit, Criminal Division | Helen M. Toor | Affirmed.
Ronald Wood v. Suzen Wood | 4/25/2014 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
In re Adoption of T.S.B. | 4/25/2014 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
In re A.M., Juvenile | 4/25/2014 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Heidi Lague v. Lawrence T. Lyons | 4/25/2014 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
In re J.W., J.W. and G.W., Juveniles | 4/25/2014 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
Jennifer Brooks (Bjurling) v. William Brooks | 4/10/2014 | Windsor Unit, Family Division | N/A | Dismissed.
Month of Decision: 05 | May
State v. Daniel Dunn | 5/5/2014 | Orange Unit, Criminal Division | Howard E. Van Benthuysen | Reverse and remand the court's denial of his home detention motion, and affirm the court's decision not to reduce bail.
Diane Levin v. Douglas C. Walker | 5/9/2014 | Lamoille Unit, Family Division | A. Gregory Rainville | Affirmed.
Suzanne E. Blanchard v. Nancy DeLuca | 5/9/2014 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Kenneth P. Felis v. Vicki-Lee Felis | 5/9/2014 | Lamoille Unit, Family Division | Dennis R. Pearson | Affirmed.
Roy H.A. Watson III v. The Village at Northshore I Association, Inc. | 5/9/2014 | Chittenden Unit, Civil Division | Dennis R. Pearson | Affirmed in part, reversed in part and remanded.
Charles Chandler v. Vermont Mutual Insurance Co. and Ronald Gifford, Individually | 5/9/2014 | Windham Unit, Civil Division | Mary Miles Teachout | Affirmed.
In re R.M., R-C.M. and C.M., Juveniles | 5/9/2014 | Washington Unit, Family Division | Thomas J. Devine | Affirmed.
Memphremagog Rentals v. Daniel Kelley | 5/9/2014 | Orleans Unit, Civil Division | Howard E. Van Benthuysen | Affirmed.
State v. Kyle Bolaski | 5/22/2014 | Windsor Unit, Criminal Division | Karen R. Carroll | Reversed and remanded.
State v. Luke Theriault | 5/29/2014 | Windsor Unit, Criminal Division | Karen R. Carroll | Amending the conditions of release for both dockets to require a curfew from 8:00 p.m. to 6:00 a.m. This new curfew condition shall be in effect beginning on May 30, 2014. All other conditions of release imposed by the trial court remain in effect.
Month of Decision: 06 | June
Timothy Miller v. Andrew Pallito, Comm of Dept of Corrections | 6/12/2014 | Franklin Unit, Civil Division | Dennis R. Pearson | Affirmed.
State v. Gregory McKirryher, Jr. | 6/12/2014 | Rutland Unit, Criminal Division | Theresa S. DiMauro | Affirmed.
Jeffrey-Michael Brandt v. Andrew Pallito, Greg Hale, Glenn Puridy and Brian Reed | 6/12/2014 | Washington Unit, Civil Division | Helen M. Toor | Affirmed.
In re Williamson Third Tier Application | 6/12/2014 | Environmental Division | Thomas G. Walsh | Affirmed.
Eejipp Ala v. Andrew Pallito, Comm of Dept of Corrections | 6/12/2014 | Orleans Unit, Civil Division | Howard E. VanBenthuysen | Affirmed.
Thomas and Ann Edwards v. Town of Stowe | 6/12/2014 | Property Valuation and Review Division | n/a | Affirmed.
Michael Cornish v. Town of Brookline | 6/12/2014 | Property Valuation and Review Division | n/a | Reversed and remanded.
Kristen Port v. Michael Port | 6/12/2014 | Chittenden Unit, Family Division | Kevin W. Griffin | Affirmed.
Rebecca Spaulding v. Dept of Labor (U.S. Precision, Employer) | 6/12/2014 | Employment Security Board | n/a | Reversed.
In re J.S.A., Juvenile | 6/12/2014 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
State v. Whalen Goucher | 6/4/2014 | Rutland Unit, Criminal Division | Theresa M. DiMauro | Affirmed.
Month of Decision: 07 | July
State v. Spencer Durham | 7/24/2014 | Bennington Unit, Criminal Division | Cortland Corsones | Affirmed.
State v. David Leo Edson | 7/24/2014 | Windsor Unit, Criminal Division | David Suntag | Affirmed.
State v. David Piquette | 7/24/2014 | Windham Unit, Criminal Division | David Suntag | Affirmed.
State v. Joseph Castegnaro | 7/24/2014 | Bennington Unit, Criminal Division | Cortland Corsones | Affirmed
State v. Ralph Bailey | 7/24/2014 | Franklin Unit, Criminal Division | Martin A. Maley | Affirmed.
Alan Tsefrekas v. Nancy Tsefrekas | 7/24/2014 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
American Express Centurion Bank v. Aaron Stine | 7/24/2014 | Chittenden Unit, Civil Division | Dennis R.Pearson | Affirmed.
State v. Spencer Durham | 7/24/2014 | Bennington Unit, Criminal Division | Nancy Corsones | Reversed and remanded.
Edward Johnson v. Andrew Pallito, Commissioner of Dept of Corrections and Carl Davis, Superintendent of NSCF | 7/24/2014 | Orleans Unit, Civil Division | Howard E. Van Benthuysen | Affirmed.
In re H.D., Juvenile | 7/24/2014 | Chittenden Unit, Family Division | Michael S. Kupersmith | Reversed and remanded.
Ronald Geraw v. Pamela Geraw | 7/24/2014 | Grand Isle Unit, Family Division | Dennis R. Pearson | Affirmed.
State v. John Swan | 7/24/2014 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
In re K.P., S.P. and A.P., Juveniles | 7/24/2014 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
In re K.B., Juvenile | 7/24/2014 | Chittenden Unit, Family Division | Kevin W. Grffin | Affirmed.
Lauren Peterson v. Chad Brown | 7/15/2014 | Addison Unit, Family Division | Linda Levitt | Dismissed as moot.
In re Stanley Mayo | 7/24/2014 | Chittenden Unit, Civil Division | Geoffrey W. Crawford/Helen M. Toor | Affirmed.
State v. Timothy Cousino | 7/31/2014 |  | Robert A. Mello and Samuel Hoar, Jr. | Affirmed in Docket No. 150-3-13 Ancr; Reversed and remanded in Docket No. 245-5-14 Ancr.
State v. DaJuan Williams | 7/29/2014 |  | James R. Cruciti | Affirmed.
Month of Decision: 08 | August
State v. Christopher Monatukwa | 8/19/2014 |  | David T. Suntag | Affirmed.
Month of Decision: 09 | September
State v. Timothy Perley | 9/26/2014 | Franklin Unit, Criminal Division | James R. Crucitti | Affirmed.
Joseph Lloyd Bertrand v. Stephanie Murray | 9/26/2014 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
Thomas Chase, Harold Chase & Ralph Chase v. Taft Hill Tree Farm, Inc., Eric Scott & Patricia Scott | 9/26/2014 | Windham Unit, Civil Division | John P. Wesley | Affirmed.
In re A.S. and E.S., Juveniles | 9/26/2014 | Washington Unit, Family Division | Thomas J. Devine | Affirmed.
Victor Chaumont v. Dept. of Labor (The Vermont Teddy Bear Co., Inc., Employer) | 9/26/2014 | Employment Security Board | n/a | Reversed and remanded.
In re R.S., C.S., J.S., D.S., B.S., S.S. and Z.S., Juveniles | 9/26/2014 | Franklin Unit, Family Division | Howard A. Kalfus | Affirmed.
In re M.R. and J.D., Juveniles | 9/26/2014 | Washington Unit, Family Division | Thomas J. Devine | Affirmed.
In re B.G. and B.G., Juveniles | 9/26/2014 | Bennington Unit, Family Division | David A. Howard | Affirmed.
In re M.W. and C.W., Juveniles | 9/26/2014 | Lamoille Unit, Family Division | Tmothy B. Tomasi | Affirmed.
Bryan E. Jones and Bryan E. Jones Trust v. Town of Proctor | 9/30/2014 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
State v. Thomas King | 9/26/2014 | Bennington Unit, Criminal Division | Cortland Corsones | Affirmed.
Jay Moody v. Wendy Moody | 9/26/2014 | Windsor Unit, Family Division | Katherine A. Hayes | Affirmed.
In re B.C.N. and N.C.N., Juveniles | 9/26/2014 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
State v. Mark A. Delude | 9/23/2014 | Caledonia Unit, Criminal Division | Samuel Hoar, Jr. | Reversed and remanded...
State v. Brian M. Thomes | 9/26/2014 | Franklin Unit, Criminal Division | Alison S. Arms | Reversed with repect to the $10,000 bail condition and remanded with instructions to strike that condition; affirmed in all other respects.
Month of Decision: 10 | October
State v. Eric Edson | 1/23/2014 | Grand Isle Unit, Criminal Division | Amy M. Davenport/Ben W. Joseph | Affirmed.
In re Roger Clinton Brown | 10/8/2014 | Windham Unit, Civil Division | John P. Wesley | Reversed and remanded.
In re Fuller Building Permit | 10/10/2014 | Environmental Division | Thomas S. Durkin | Affirmed.
In re H.B., Juvenile | 10/30/2014 | Bennington Unit, Family Division | David A. Howard | Affirmed. The mandate shall issue on the date of this entry order,
Mark White v. Denise White | 10/31/2014 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
Kelley O'Brien v. Andrew Pallito, et al. | 10/31/2014 | Washington Unit, Civil Division | Michael S. Kupersmith/Robert R. Bent | Affirmed.
Kayla Eaton and Robert Eaton v. Norman Watts and Watts Law Firm, P.C. | 10/31/2014 | Windsor Unit, Civil Division | Robert P. Gerety, Jr. | Affirmed.
State v. Jay Allard | 10/31/2014 | Bennington Unit, Criminal Division | David A. Howard/Cortland Corsones | Affirmed.
Edward Johnson v. Andrew Pallito, Commissioner of the Dept. of Corrections | 10/31/2014 | Orleans Unit, Civil Division | Howard E. Van Benthuysen | Affirmed.
Jesse deVos v. Kimberly Volk | 10/31/2014 | Addison Unit, Family Division | Linda Levitt | Affirmed.
City of Burlington v. Bilmar Team Cleaners, A Vermont Partnership, et al. | 10/31/2014 | Chittenden Unit, Civil Division | Dennis R. Pearson | Affirmed.
Kayla Herrick v. Edmund Vigneault | 10/31/2014 | Windsor Unit, Family Division | Harold E. Eaton, Jr. | Affirmed.
Katherine Amy O'Neil v. Shawn O'Neil | 10/31/2014 | Addison Unit, Family Division | Robert A. Mello | Affirmed.
Julia Dixon v. Geoffrey Dixon | 10/31/2014 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
Kevin Barrup v. Tammy Barrup | 10/31/2014 | Orleans Unit, Family Division | Howard E. Van Benthuysen | Affirmed.
Donald Matteson v. Dept. of Labor (Charbonneau Design and Construction LLC, Employer) | 10/31/2014 | Employment Security Board | n/a | Affirmed.
In re M.M., Juvenile | 10/31/2014 | Caledonia Unit, Family Division | M. Kathleen Manley | Affirmed.
In re T.D. and B.D., Juveniles | 10/31/2014 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
In re D.D., Juvenile | 10/31/2014 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
Jonathan H. Dodge v. Governor Peter Shumlin | 10/31/2014 |  | Howard E. Van Benthuysen | Affirmed.
Month of Decision: 11 | November
Howard Wilkinson v. Westminster Board of Abatement | 11/17/2014 | Windham Unit, Civil Division | John P. Wesley | Affirmed.
Month of Decision: 12 | December
In re Joseph Bruyette | 12/12/2014 | Windham Unit, Civil Division | Karen R. Carroll | Affirmed.
John Stokes v. State | 12/12/2014 | Addison Unit, Civil Division | Robert A. Mello | Affirmed.
State v. Joshua Laraway | 12/12/2014 | Addison Unit, Criminal Division | Robert A. Mello | Affirmed.
Andrew Mayer v. Veronica Boord | 12/12/2014 | Addison Unit, Civil Division | Linda Levitt/Robert A. Mello | Affirmed.
Karen Hecht v. Department of Labor (Fletcher Allen Health Care, Employer) | 12/12/2014 | Employment Security Board | n/a | Affirmed.
In re Castleton Expansion Renovation Permit | 12/12/2014 | Environmental Division | Thomas S. Durkin | Affirmed.
Tony Taylor v. Department of Labor (Mastaler Cleaning Service Co. Inc., Employer) | 12/12/2014 | Employment Security Board | n/a | Affirmed.
In re J.P., J.J., A.J. & A.J., Juveniles | 12/12/2014 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
In re A.M., Juvenile | 12/12/2014 | Chittenden Unit, Family Division | James R. Crucitti | Affirmed.
In re B.S., Juvenile | 12/12/2014 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
In re C.C., C.C. and B.C., Juveniles | 12/12/2014 | Bennington Unit, Family Division | David A. Howard | Affirmed.
Robert Jones, Janet Jones and Jean Bombard v. James Hart | 12/16/2014 | Windsor Unit, Civil Division | William D. Cohen\Mary Miles Teachout | Affirmed.
In re D.C., Juvenile | 12/17/2014 | Caledonia Unit, Family Division | M. Kathleen Manley | Affirmed.
In re O.D., Juvenile | 12/18/2014 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
In re B.R., Juvenile | 12/22/2014 | Franklin Unit, Family Division | Kevin W. Griffin | Affirmed.
Year of Decision: 2013
Month of Decision: 01 | January
State v. Quondell Knight | 1/4/2013 | Bennington Unit, Criminal Division | Cortland Corsones | Affirmed.
Month of Decision: 02 | February
Bobbi Jo Stellato v. McCurtis Anthony Williams | 2/12/2013 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
Herman LeBlanc v. Glen Brown | 2/25/2013 | Orleans Unit, Civil Division | Robert R. Bent | Affirmed.
In re D.D., Juvenile | 2/7/2013 | Windham Unit, Family Division | John P. Wesley | Affirmed.
In re S.M., Juvenile | 2/7/2013 | Chittenden Unit, Family Division | Edward J. Cashman | Affirmed.
In re T.T., Juvenile | 2/7/2013 | Lamoille Unit, Family Division | Dennis R. Pearson | Affirmed.
Kashka Orlow v. Erika Dinkel | 2/14/2013 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Kimberly Kim v. Larry Hone | 2/7/2013 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
Krista Greenstein v. Bret Greenstein | 2/7/2013 | Chittenden Unit, Family Division | A. Gregory Rainville | Reversed and remanded.
Lisa Crown v. Jeffrey Lawson | 2/7/2013 | Caledonia Unit, Civil Division | Robert P. Gerety, Jr. | Affirmed.
Maurice Connary v. Off. Callie Field, VT State Police and State of Vermont | 2/14/2013 | Essex Unit, Civil Division | M. Kathleen Manley | Affirmed.
Showntie Dobrynski v. Gerald Dobrynski | 2/14/2013 | Essex Unit, Family Division | Robert P. Gerety, Jr. | Remanded for the superior court to include in the divorce order specific requirements, including a timeline, for the transfer to wife of encumbered marital property distributed to her; in all other respects, the superior court’s judgment is affirmed.
State v. Dennis Rose | 2/12/2013 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
State v. Frank Fellows | 2/12/2013 | Chittenden Unit, Criminal Division | Robert P. Gerety, Jr. | Affirmed.
State v. Ladarris Tunstall | 2/7/2013 | Washington Unit, Criminal Division | Howard E. Van Benthuysen | Affirmed.
Allen Rheaume v. Robert Ide Robert Ide, Commissioner of Department of Motor Vehicles, Daniel Porter, Carl Roberts and Brian Quinn | 2/7/2013 | Franklin Unit, Civil Division | Dennis R. Pearson | Affirmed.
Allison Gould v. Stuart Robinson | 2/25/2013 | Chittenden Unit, Family Division | Alison S. Arms | Reversed, with cause transferred to the Superior Court, Chittenden Unit, Civil Division.
In re Bernice C. Billewicz Guardianship | 2/7/2013 | Rutland Unit, Civil Division | Mary Miles Teachout | Affirmed.
Month of Decision: 03 | March
In re T.S., Juvenile | 3/13/2013 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
Lorrie Tetreault v. David Tetreault | 3/13/2013 | Washington Unit, Family Division | Thomas A. Zonay | Affirmed.
State of Vermont v. Michael Rinaldo | 3/13/2013 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
State v. David C. Boglioli | 3/13/2013 | Windham Unit, Criminal Division | Amy M. Davenport/Karen R. Carroll | Affirmed.
In re Carrie Newton | 3/13/2013 | Rutland Unit, Civil Division | Mary Miles Teachout | Affirmed.
State v. Zak Winston | 3/13/2013 | Washington Unit, Criminal Division | Howard E. VanBent | Affirmed.
Rickey Thibodeau v. Ashley Blanchard | 3/18/2013 | Windsor Unit, Family Division | William D. Cohen | Affirmed.
Marcia Ratner v. Village Square at Pico Condominium Owners Association, Richard Fowler, David Crossman and Matthew "Bud" Solano | 3/13/2013 | Rutland Unit, Civil Division | Mary Miles Teachout | Affirmed.
Ronald E. Pollock and Milton R. Pollock v. Douglas Butler | 3/13/2013 | Addison Unit, Civil Division | Helen M. Toor | Affirmed.
Richard J. Fleming, Jr. v. Joni Fleming | 3/13/2013 | Windham Unit, Family Division | Karen R. Carroll | Affirmed.
Christopher M. Wurster v. Karen Wurster-Sinex | 3/13/2013 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
Jermaine Holder v. Andrew Pallito | 3/13/2013 | Franklin Unit, Civil Division | Martin A. Maley | Remanded for further proceedings on plaintiff’s constitutional claim.
In re I.H., J.H. and D.G., Juveniles | 3/13/2013 | Addison Unit, Family Division | Helen M. Toor | Affirmed.
Peter Vieta v. Dept. of Labor (Med Associates, Inc., Employer) | 3/19/2013 | Employment Security Board | n/a | Reversed.
Month of Decision: 04 | April
Julie Proia v. Julius Proia , Jr. | 4/10/2013 | Caledonia Unit, Family Division | Robert P. Gerety, Jr. | Affirmed
State v. Jeffrey Brandt | 4/10/2013 | Chittenden Unit, Criminal Division | James R. Crucitti | Affrirmed.
Miriam Levin, Margaret Grundstein and Leon Grundstein v. Robert Grundstein | 4/18/2013 | Lamoille Unit, Civil Division | Dennis R. Pearson | Affirmed.
In re J.D. | 4/18/2013 | Human Services Board | n/a | Affirmed.
Carol Sinchak v. John Sinchak | 4/16/2013 | Chittenden Unit, Family Division | A. Gregory Rainville | Reversed and remanded.
In re. A.W. and J.W., Juveniles | 4/10/2013 | Lamoille Unit, Family Division | Dennis R. Pearson | Affirmed.
In re Appeal of Susan and Joseph Tropeano | 4/10/2013 | Human Services Board | n/a | Affirmed.
Mark Bilodeau v. Cristina Bilodeau | 4/10/2013 | Windsor Unit, Family Division | William D. Cohen | Affirmed with the additional limitation imposed on wife's right to remove personal property from the marital home as set forth above.
Joel Langlois v. Mary Langlois | 4/10/2013 | Bennington Unit, Family Division | David A. Howard | Affirmed.
Becky Nystrom, Scott Nystrom and Laurie Nystrom v. Casey J. Hafford | 4/10/2013 | Windham Unit, Civil Division | John P. Wesley | Affirmed.
In re J.S., Juvenile | 4/10/2013 | Caledonia Unit, Family Division | M. Kathleen Manley | Affirmed.
In re Allen Rheaume | 4/18/2013 | Franklin Unit, Civil Division | Martin A. Maley | Affirmed.
State v. Charles Muldowney |  | Windham Unit, Criminal Division | David Suntag | The condition prohibiting defendant from discussing with wife the pending charges, the two children in foster care and their domestic circumstances preceding the pending charges is affirmed.
Month of Decision: 05 | May
State v. Corey Richardson | 5/8/2013 | Orange Unit, Criminal Division | Robert R. Bent | Affirmed.
William B. Birch v. Alan G. Jesseman | 5/8/2013 | Orange Unit, Civil Division | Harold E. Eaton, Jr. | Affirmed.
State v. Scott W. Whitney | 5/8/2013 | Windsor Unit, Criminal Division | M. Patricia Zimmerman | Affirmed.
Isaac Faham v. Department of Corrections | 5/8/2013 | Windsor Unit, Civil Division | Theresa S. DiMauro | Affirmed.
Matthew Aldrich v. Jennifer Aldrich Haselman | 5/8/2013 | Franklin Unit, Family Division | A. Gregory Rainville | Affirmed.
Warren Vail, III v. Agency of Transportation, et al. | 5/8/2013 | Washington Unit, Civil Division | Michael S. Kupersmith | Affirmed.
Alan and Rachel Yeager v. Jack and Dawn Menard | 5/8/2013 | Chittenden Unit, Civil Division | Timothy B. Tomasi | Affirmed.
In re Ronald D. Combs | 5/8/2013 | Franklin Unit, Civil Division | Dennis R. Pearson | Affirmed.
In re B.P. and K.P., Juveniles | 5/8/2013 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
In re T.P., Juvenile | 5/8/2013 | Orleans Unit, Family Division | M. Kathleen Manley | Affirmed.
State of Vermont v. Stephen Messier | 5/31/2013 | Orange Unit, Criminal Division | Timothy B. Tomasi | Affirmed.
State v. Spencer Durham | 5/22/2013 | Bennington Unit, Criminal Division | Cortland T. Corsones | Dismissed for lack of jurisdiction.
Month of Decision: 06 | June
State v. Frank Berard | 6/12/2013 | Chittenden Unit, Criminal Division | James R. Crucitti | Affirmed.
State v. Floyd A. Amidon | 6/12/2013 | Bennington Unit, Criminal Division | David A. Howard | Affirmed
Anthony Deyo v. Andrew Pallito, Commissioner of the Dept. of Corrections, et al. | 6/3/2013 | Washington Unit, Civil Division | Robert R. Bent | Affirmed.
Kaitlin Barry v. Chris C. Khamnei | 6/12/2013 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Donald D. Dorr d/b/a D. Door Septic v. Paul M. LaCoste & Debra J. LaCoste | 6/12/2013 | Bennington Unit, Civil Division | Katherine A. Hayes | Affirmed.
Misty Bowen v. Terrel Spearman | 6/12/2013 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Logan Nutter v. Charles R. Fenoff, Jr. | 6/12/2013 | Caledonia Unit, Civil Division | Theresa S. DiMauro | Affirmed.
Merchants Bank v. Ann M. Furey | 6/12/2013 | Addison Unit, Civil Division | Helen M. Toor | Affirmed.
In re T.A.Z., A.M., B.M. & J.M., Juveniles / In re B.M. & J.M., Juveniles | 6/12/2013 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
Michele Tattoli v. Christopher Colm | 6/12/2013 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
In re Richard Laws | 6/12/2013 | Washington Unit, Civil Division | Robert R. Bent | Affirmed.
In re I.W., Juvenile | 6/12/2013 | Washington Unit, Family Division | Amy M. Davenport | Affirmed.
John Viskup v. Juliane L. Hegle (Viskup) | 6/12/2013 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Holly Johnson v. Peter Johnson | 6/12/2013 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
In re H.B. & A.B., Juveniles | 6/12/2013 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
Month of Decision: 07 | July
Troy D. Rainey v. Tania Rainey | 7/11/2013 | Caledonia Unit, Family Division | Mary Miles Teachout | Affirmed.
In re I.L., Juvenile | 7/11/2013 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
Juanita Belleville v. John N. Young | 7/11/2013 | Windham Unit, Family Division | John P. Wesley | Affirmed.
Zohara Zarfati v. Clinton Eirmann | 7/11/2013 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
Laurie A. Cenate v. Randy Martelle | 7/11/2013 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
Mary Duggan v. Dept. of Labor (Addison-Rutland Supervisory Union, Employer) | 7/11/2013 | Employment Security Board | n/a | Affirmed.
In re T.G., Juvenile | 7/11/2013 | Windsor Unit, Family Division | Howard A. Kalfus | Affirmed.
In re M.A., Juvenile / In re J.A., Juvenile | 7/11/2013 | Windsor Unit, Family Division | Katherine A. Hayes | Affirmed.
In re A.M. and A.M., Juveniles | 7/11/2013 | Washington Unit, Family Division | Walter M. Morris, Jr., (Ret.) | Affirmed.
In re A.N., Juvenile | 7/11/2013 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
In re S.S., A.S. and L.S., Juveniles | 7/11/2013 | Bennington Unit, Family Division | David A. Howard | Affirmed.
In re B.S., R.M. and D.W., Juveniles | 7/11/2013 | Windsor Unit, Family Division | Katherine A. Hayes | Affirmed.
In re Rosemary A. Macero | 7/31/2013 | Professional Responsibility Board | n/a | The Court hereby reinstates petitioner Rosemary A. Macero as a member of the bar of the State of Vermont.
Month of Decision: 09 | September
Edward Johnson v. Andrew Pallito, Commissioner of Dept. of Corrections, Dr. Abigail Hager and Dr. Westinghouse | 9/13/2013 | Orleans Unit, Civil Division | Howard E. Van Benthuysen | Affirmed.
State v. Scott Manfredi | 9/13/2013 | Rutland Unit, Criminal Division | Theresa S. DiMauro | Affirmed.
Office of Child Support/Phyliss Trout (Brady) v. Daniel Quinn | 9/13/2013 | Windsor Unit, Family Division | William D. Cohen | Affirmed.
In re L.Z., Juvenile | 9/13/2013 | Chittenden Unit, Family Division | Alison S. Arms | Affirmed.
Amanda Mallette v. George Lafontaine III | 9/13/2013 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
In re A.H., Juvenile | 9/13/2013 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
Whitney Calkins v. Kenneth Smith | 9/13/2013 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
In re A.P., Juvenile | 9/13/2013 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
In re Leonard & Sayour Permitted Use Zoning Permit | 9/13/2013 | Environmental Division | Thomas S. Durkin | Affirmed.
Keith Judd v. Secretary of State, et al. | 9/13/2013 | Washington Unit, Civil Division | Robert R. Bent | Affirmed.
Margaret Murray v. CIty of Burlington | 9/13/2013 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
State of Vermont v. Jonathan Houle | 9/6/2013 | Essex Unit, Criminal Division | Mary M. Teachout | The Essex Superior Court, Criminal Division, shall hold a bail review hearing as soon as possible under the procedures specified in 13 V.S.A. §7554(d)(2) and decide the motion as soon as possible thereafter.
Donald L. Bletz Sr. & Bruce Van Guilder v. John J. Welch, Jr., Esq. | 9/13/2013 | Rutland Unit, Civil Division | Mary Miles Teachout | Affirmed in part, reversed in part.
State of Vermont v. Jonathan Houle | 9/26/2013 | Essex Unit, Criminal Division | Robert R. Bent | Affirmed.
Month of Decision: 10 | October
Lonnie Chester, Administrator of the Estate of Philomena Weingarten v. Albert Weingarten a/k/a Albert Von Weingarten and Mary Weingarten a/k/a Mary Von Weingarten | 10/11/2013 | Orleans Unit, Civil Division | Robert R. Bent | Affirmed.
Emmanuel Riby-Williams v. Mary Riby-Williams | 10/11/2013 | Washington Unit, Family Division | Howard E. Van Benthuysen | The superior court's August 29, 2012 order is reversed, and the matter is remanded for the court to reconsider its division of the marital property in light of this entry order.
Nicole Williams v. James McMillan | 10/11/2013 | Chittenden Unit, Family Division | Linda Levitt | Reversed and remanded.
Peter Dernier v. Town of Weston | 10/11/2013 | Property Valuation and Review Division | n/a | Affirmed.
John Uckele v. Johana Harris, Thomas Harris and Allstate Insurance | 10/11/2013 | Grand Isle Unit, Civil Division | Dennis R. Pearson | Affirmed.
Deutsche Bank National Trust v. Bruce Merritt, Gloria King Merritt and Indymac Bank | 10/11/2013 | Windsor Unit, Civil Division | Robert P. Gerety, Jr. | Appeal dismissed.
State v. Jack Wallace | 10/11/2013 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
State v. Tiffany Marcotte | 10/11/2013 | Orleans Unit, Criminal Division | Howard E. Van Benthuysen | The provision for interest is struck, and, in all other respects the restitution order is affirmed.
In re Estate of Danielle Morin | 10/11/2013 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Timothy Miller v. Mortimer Kaufman, Mary Ann Bovat, & Clyde Bovat | 10/11/2013 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Appeal dismissed.
Kayla Eaton and Robert Eaton v. Cleary, Shahi & Aicher, Attorneys and David Cleary and Thomas Aicher, Individually | 10/11/2013 | Rutland Unit, Civil Division | Nancy Corsones | Affirmed.
In re A.W., Juvenile | 10/11/2013 | Franklin Unit, Family Division | Martin A. Maley | Affirmed.
In re A.T. and T.T., Juveniles | 10/11/2013 | Orange Unit, Family Division | Timothy B. Tomasi | Affirmed.
In re J.R. | 10/11/2013 | Rutland Unit, Family Division | Nancy Corsones | Affirmed; mandate to issue forthwith.
In re J.H., Juvenile | 10/11/2013 | Orleans Unit, Family Division | M. Kathleen Manley | Affirmed.
In re C.B., Juvenile | 10/18/2013 | Chittenden Unit, Family Division | Thomas J. Devine | Reversed.
Month of Decision: 11 | November
Jennifer Brooks v. William Brooks | 11/20/2013 | Windsor Unit, Family Division | William D. Cohen | amended final divorce order is vacated & original final divorce order is renistated, except that the court may offset against wife's required $15,000 equalizing payment the sums husband owes wife due to his failure to abide by the court's orders, et al.
In re Ryan Brink | 11/20/2013 | Franklin Unit, Civil Division | Martin A. Maley | Affirmed.
Dwayne Calloway v. Andrew Pallito, Commissioner of Dept. of Corrections | 11/20/2013 | Caledonia Unit, Civil Division | Mary Miles Teachout | Affirmed.
Town of Colchester v. Robert K. Andres | 11/20/2013 | Environmental Division | Thomas S. Durkin | Affirmed in part, reversed in part, and remanded.
In re C.G., Juvenile | 11/20/2013 | Washington Unit, Family Division | Thomas J. Devine | Affirmed.
State v. Donald Shepherd | 11/20/2013 | Grand Isle Unit, Criminal Division | Dennis R. Pearson | Reversed and remanded.
In re Robert Jones | 11/20/2013 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | The superior Court's February 20, 2013 decision is affirmed, but the matter is remanded, et al.
Mark Brady & Mary Brady v. Addison Broadcasting Co., Inc., Radio Broadcasting, Inc. & Steven Silberberg | 11/20/2013 | Addison Unit, Civil Division | Helen M. Toor | Remanded for additional proceedings consistent with this opinion.
Albert Gionet v. Bernadette Bousquet | 11/20/2013 | Addison Unit, Civil Division | Helen M. Toor | The superior court's dismissal of plaintiff's defamation lawsuit and its award of partial attorney's fees are affirmed. The matter is remanded, et al.
Michael Vereline v. Marybeth Vereline | 11/20/2013 | Caledonia Unit, Family Division | Robert P. Gerety, Jr. | Reversed and remanded.
Valerie Zimmerman & PopXue America, LLC v. Bruce Bjornlund, Esq. | 11/20/2013 | Washington Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Amy Gibbons v. Bradley Burns | 11/20/2013 | Chittenden Unit, Family Division | Robert A. Mello | Affirmed.
Keri Streeter v. Trevor James | 11/20/2013 | Addison Unit, Family Division | Helen M. Toor | Affirmed.
In re A.L. and A.L., Juveniles | 11/20/2013 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Gordon E. Campbell | 11/5/2013 | Windsor Unit, Civil Division | Harold E. Eaton, Jr. | Dismissed.
State v. Vincent D. Costantino | 11/27/2013 | Bennington Unit, Criminal Division | Nancy S. Corsones | For the reasons stated herein, defendant shall continute to be held without bail pursuant to 13.V.S.A. § 7553a.
Month of Decision: 12 | December
State v. Jason DeGreenia | 12/18/2013 | Orleans Unit, Criminal Division | Dennis R. Pearson | Affirmed.
In re Victor Hall | 12/18/2013 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Stacy Hoechner v. Ernest Hoechner | 12/18/2013 | Chittenden Unit, Family Division | Linda Levitt | Reversed and remanded.
Michael Bandler v. Majestic Car Rental Group, Inc. | 12/17/2013 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
In re E.B., Juvenile | 12/18/2013 | Bennington Unit, Family Division | David A. Howard | Affirmed.
In re C.C., S.C. & A.C., Juveniles | 12/18/2013 | Washington Unit, Family Division | Thomas J. Devine | Affirmed.
Misty Bowen v. Terrel Spearman | 12/18/2013 | Chittenden Unit, Family Division | Linda Levitt | Appeal dismissed.
Kimberly Tillotson v. John Kidder | 12/18/2013 | Washington Unit, Family Division | Thomas J. Devine | Affirmed.
In re J.G. and A.G., Juveniles | 12/18/2013 | Caledonia Unit, Family Division | M. Kathleen Manley | Affirmed.
Kristen Chambers (Anton) v. George Chambers | 12/18/2013 | Windsor Unit, Family Division | Harold E. Eaton, Jr. | Affirmed.
In re J.T. and E.T., Juveniles | 12/18/2013 | Windsor Unit, Family Division | Katherine A. Hayes | Affirmed.
In re J.F., Juvenile | 12/18/2013 | Windsor Unit, Family Division | Howard A. Kalfus, Acting Judge, Specially Assigned | Affirmed.
State v. Joshua J. Parizo | 12/20/2013 | Franklin Unit, Criminal Division | James R. Crucitti | Affirmed.
In re John Davis Buckley, Esq. | 12/9/2013 | Professional Responsibility Board | N/A | Reinstatment, subject to conditions.
Year of Decision: 2012
Month of Decision: 01 | January
State v. William Mogerley | 1/26/2012 | Windham Unit, Criminal Division | Karen R. Carroll | Affirmed.
James Ghia v. Town of Ludlow | 1/30/2012 | Property Valuation and Review Division | n/a | Affirmed.
Allison Lary v. Richard Goldsborough | 1/26/2012 | Chittenden Unit, Family Division | Linda Levitt/M. Patricia Zimmerman/Thomas J. Devine | Affirmed.
Mark Bean v. Herbert Bickford | 1/26/2012 | Caledonia Unit, Civil Division | M. Kathleen Manley/Alan W. Cook | Affirmed.
In re Richard's Site Plan Amendment Application | 1/26/2012 | Environmental Division | Merideth Wright | Affirmed.
Kaser USA, LLC v. Seabreeze Trading Corp. | 1/26/2012 | Orange Unit, Civil Division | Harold E. Eaton, Jr. | Affirmed.
State v. Stephen Bain | 1/26/2012 | Windham Unit, Criminal Division | David Suntag | Affirmed.
In re I.C., M.C., A.C. and A.H., Juveniles | 1/26/2012 | Caledonia Unit, Family Division | M. Kathleen Manley | Affirmed.
David Holcomb v. Andrew Pallito | 1/26/2012 | Chittenden Unit, Civil Division | Helen M. Toor | Affirmed.
In re M.B. and K.B., Juveniles | 1/26/2012 | Chittenden Unit, Family Division | Edward J. Cashman | Affirmed.
In re A.M., G.M., J.M. & M.M., Juveniles | 1/26/2012 | Windsor Unit, Family Division | Walter M. Morris, Jr. | Affirmed.
Month of Decision: 02 | February
Kit (Farrand) Slayton/OCS v. Jeffrey Hill | 2/2/2012 | Lamoille Unit, Family Division | Dennis R. Pearson | Affirmed.
Gerald Gugino v. National Grange Mutual Insurance | 2/2/2012 | Windham Unit, Civil Division | John P. Wesley | Affirmed.
Lisa Patnode v. Garrison Urette | 2/2/2012 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Michael Branch Electrical v. Adam Wagner, Christine Wagner and August & Sterling, LLC | 2/6/2012 | Windsor Unit, Civil Division | Katherine A. Hayes | Affirmed.
Joseph Franz v. Judith Franz | 2/10/2012 | Chittenden Unit, Family Division | Matthew I. Katz | Affirmed.
Month of Decision: 03 | March
State v. Mark Abair | 3/15/2012 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
State v. Michael Williams | 3/15/2012 | Bennington Unit, Criminal Division | Davd A. Howard | Affirmed.
State v. Edwin Herbert Martin | 3/15/2012 | Windham Unit, Criminal Division | David Suntag | Affirmed.
In re Paul Miglorie | 3/15/2012 | Rutland Unit, Civil Division | William D. Cohen/Mary Miles Teachout | Affirmed.
Michael Rinaldo v. Bennington Self Storage | 3/15/2012 | Bennington Unit, Civil Division | John P. Wesley | Affirmed.
Stephanie Foster v. Darren Brady | 3/15/2012 | Orleans Unit, Family Division | Robert R. Bent | Affirmed.
Derek Allen and Melinda Allen v. James Moorcroft | 3/15/2012 | Washington Unit, Civil Division | Geoffrey W. Crawford | The court's decision is affirmed with the exception of its denial of defendant's counterclaim for insurance proceeds, which is reversed. This case is remanded for entry of judgment on defendant's counterclaim in the amount of $1221.
In re L.B., G.B. & L.B., Juveniles | 3/15/2012 | Caledonia Unit, Family Division | Edward J. Cashman | Affirmed.
In re C.P., Juvenile | 3/15/2012 | Chittenden Unit, Family Division | Edward J. Cashman | Affirmed.
Tara (Carter) Trappaso v. Jamie Carter | 3/15/2012 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Keith Russell Judd v. Secretary of State | 3/15/2012 | Washington Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
In re X.L. and N.L., Juveniles | 3/15/2012 | Bennington Unit, Family Division | Karen R. Carroll | Affirmed.
In re S.M. & C.M., Juveniles | 3/15/2012 | Addison Unit, Family Division | David A. Jenkins (Ret.) | Affirmed.
Month of Decision: 04 | April
State v. Matthew McGrath | 4/26/2012 | Grand Isle Unit, Criminal Division | Ben W. Joseph | Affirmed.
State v. Paul Bryan Thibodeau-O'Connor | 4/26/2012 | Windham Unit, Criminal Division | David Suntag | Affirmed.
Robert Christian v. Karen Lawton | 4/30/2012 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
In re Appeal of J.P. | 4/26/2012 | Human Services Board | n/a | Affirmed.
Lucas Ashley v. Agency of Transportation | 4/26/2012 | Washington Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
In re Grievance of Clint Glover | 4/26/2012 | Labor Relations Board | n/a | Affirmed.
Victor Calhoun v. Dawn Calhoun | 4/26/2012 | Washington Unit, Family Division | Brian J. Grearson | Affirmed.
In re M.V. | 4/26/2012 | Human Services Board | n/a | Affirmed.
Stephen Bain v. Peter Potanas, William Lawhorn and Andrew Pallito | 4/26/2012 | Windsor Unit, Civil Division | Theresa S. DiMauro | Affirmed.
In re B.H., Juvenile | 4/26/2012 | Addison Unit, Family Division | Helen M. Toor | Affirmed.
Month of Decision: 05 | May
In re Verizon Wireless Barton Act 250 Permit | 5/1/2012 | Environmental Division | Thomas S. Durkin | Affirmed.
State v. Norman J. Lizotte | 5/31/2012 | Windham Unit, Criminal Division | David Suntag | Affirmed.
Martin Webster v. Steve Anderson | 5/31/2012 | Windham Unit, Civil Division | John P. Wesley | Affirmed.
State v. Arthur C. Bigelow | 5/31/2012 | Windham Unit, Criminal Division | David Suntag | Affirmed.
Mark Ashline v. Donella Ashline | 5/31/2012 | Franklin Unit, Family Division | A. Gregory Rainville | Affirmed.
Andrew Zoito, Jr. v. Town of Stamford | 5/7/2012 | Property Valuation and Review Division | n/a | Reversed with instructions to the Town of Stamford to reinstate the 2009 listed value of taxpayer's property.
State v. Benjamin Willoughby | 5/30/2012 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
In re M.A., Juvenile | 5/31/2012 | Chittenden Unit, Family Division | Alison Arms | Affirmed.
Jeffrey Lamothe v. Cohen & Rice Law Firm and Julie Lamothe, Rebecca Rice, Esq. | 5/31/2012 | Rutland Unit, Civil Division | Mary Miles Teachout | Affirmed.
Month of Decision: 07 | July
In re Ronald Combs | 7/11/2012 | Franklin Unit, Civil Division | Ben W. Joseph | Reversed and remanded.
Month of Decision: 09 | September
Allen Rheaume v. Daniel Maguire | 9/26/2012 | Chittenden Unit, Civil Division | Brian J. Grearson | Affirmed.
Jonathan Lasek v. Laurie Celik | 9/26/2012 | Rutland Unit, Civil Division | Mary Miles Teachout | Order denying plantiff's motion to amend complaint is reversed and remanded. In all other respects, affirmed.
St. Albans Electric d/b/a Total Home Center v. John Burgess and Virginia Burgess | 9/27/2012 | Franklin Unit, Civil Division | Martin A. Maley | Affirmed.
In re C.B., Juvenile | 9/26/2012 | Bennington Unit, Civil Division | Karen R. Carroll | Affirmed.
In re R.M., Juvenile | 9/26/2012 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
In re M.W., Juvenile | 9/26/2012 | Bennington Unit, Family Division | Karen R. Carroll | Affirmed.
In re H.R., Juvenile | 9/26/2012 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
In re D.B., C.B., N.B. and T.B., Juveniles | 9/27/2012 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
In re N.L. and K.S., Juveniles | 9/26/2012 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
In re G.B., Juvenile | 9/26/2012 | Chittenden Unit, Family Division | Timothy B. Tomasi | Affirmed.
In re S.T., B.T. and S.T., Juveniles | 9/26/2012 | Franklin Unit, Family Division | A. Gregory Rainville | Affirmed.
In re E.C., Juvenile | 9/26/2012 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
State of Vermont v. Jeffrey M. Brandt | 9/26/2012 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
State of Vermont v. James Menize, Jr. | 9/26/2012 | Lamoille Unit, Criminal Division | Dennis R. Pearson | Affirmed.
State of Vermont v. Matthew Voog | 9/26/2012 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
Jessica Woodward v. Richard Woodward | 9/26/2012 | Caledonia Unit, Family Division | M. Kathleen Manley | Affirmed.
Nina Keus v. Andrew Pallito, Commissioner of the Department of Corrections | 9/26/2012 | Franklin Unit, Civil Division | Martin A. Maley | Reversed.
Month of Decision: 10 | October
State v. Nebuchadnezzar Watson | 10/3/2012 |  | Robert A. Mello | The state's motion to hold the defendant without bail is granted.
Month of Decision: 11 | November
Allen Rheaume v. Andrew A. Pallito, Commissioner of the Dept of Corrections | 11/14/2012 | Windsor Unit, Civil Division | Theresa S. DiMauro | Affirmed.
State v. Leanne Gorman | 11/27/2012 | Washington Unit, Criminal Division | Howard E. Van Benthuysen | Affirmed.
State v. Michael T. LaMotte | 11/8/2012 | Windsor Unit, Criminal Division | M. Patricia Zimmerman | Affirmed.
Diane LeFebvre v. Corey LeFebvre and Sarah LeFebvre | 11/8/2012 | Franklin Unit, Civil Division | Martin A. Maley | Affirmed.
Christine Castro v. Robert Doyle | 11/8/2012 | Rutland Unit, Family Division | Nancy Corsones | Reversed and remanded.
State v. Joseph Bruyette | 11/8/2012 | Rutland Unit, Criminal Division | Cortland Corsones | Affirmed.
State v. Shawna Thorpe | 11/8/2012 | Addison Unit, Criminal Division | Helen M. Toor | Affirmed.
Stephan L. Petrie v. Town of Colchester | 11/8/2012 | Property Valuation and Review Division | n/a | Affirmed.
State v. Daniel John Guyette | 11/8/2012 | Rutland Unit, Criminal Division | Theresa S. DiMauro | Affirmed.
In re K.B., Juvenile | 11/8/2012 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
In re J.L., Juvenile | 11/8/2012 | Chittenden Unit, Family Division | A. Gregory Rainville | Affirmed.
In re H.F., Juvenile | 11/8/2012 | Grand Isle Unit, Family Division | Martin A. Maley | Affirmed.
State v. Misty Smith | 11/8/2012 | Franklin Unit, Criminal Division | Robert A. Mello | Affirmed.
In re Ryan Brink | 11/1/2012 | Franklin Unit, Civil Division | Martin A. Maley | Dismissed and remanded.
Month of Decision: 12 | December
State of Vermont v. Leo Corbeil | 12/13/2012 | Washington Unit, Criminal Division | Howard E. Van Benthuysen | The order of the superior court, criminal division, entered on February 15, 2012, is reversed, and the matter is remanded with instructions for the court to deny defendant’s motion to suppress and dismiss.
Ashley Smith v. Stephen Rawson | 12/13/2012 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
State of Vermont v. Cecil Vivian | 12/13/2012 | Windham Unit, Criminal Division | David Suntag | Affirmed.
Todd Swim a/k/a Todd C. Swim v. Margaret (Swim) O'Neill | 12/13/2012 | Windham Unit, Family Division | John P. Wesley | Affirmed.
Dawn Adamson v. Jeffrey Dodge | 12/13/2012 | Chittenden Unit, Family Division | Brian J. Grearson | Affirmed.
In re A.E., Juvenile | 12/13/2012 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
In re I.R., S.R. and A.D., Juveniles | 12/13/2012 | Addison Unit, Family Division | Edward J. Cashman | Affirmed.
In re L.O. and M.M., Juveniles | 12/13/2012 | Franklin Unit, Family Division | Linda Levitt | Affirmed.
State of Vermont v. Darrell F. Day | 12/13/2012 | Bennington Unit, Criminal Division | Karen R. Carroll | Affirmed.
Dayco, Inc v. Al Bergeron and Paula Bergeron d/b/a Bergeron’s Service Center | 12/13/2012 | Windsor Unit, Civil Division | Theresa S. DiMauro | Affirmed.
State of Vermont v. James T. Burke | 12/13/2012 | Chittenden Unit, Criminal Division | James R. Crucitti | Affirmed.
Bernice Singley v. Department of Labor (World Learning, Inc., Employer) | 12/13/2012 | Employment Security Board | n/a | Affirmed.
Linda Birkenbach and Timothy James v. Tamar Bouchard | 12/13/2012 | Chittenden Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Year of Decision: 2011
Month of Decision: 01 | January
Floyd Kilburn v. Dept. of Labor (Jolley Associates, Employer) | 1/27/2011 | Employment Security Board | n/a | Affirmed.
In re Losier Variance Application | 1/27/2011 | Environmental Division | Thomas S. Durkin | Affirmed.
In re N. H., Juvenile | 1/27/2011 | Addison Unit, Family Division | Alden T. Bryan | Affirmed.
In re D.F. and A.F., Juveniles | 1/27/2011 | Windsor Unit, Family Division | M. Kathleen Manley | Affirmed.
Albert Gionet v. Dartmouth Medical Center, Dr. William Rosen & Dr. Rosen's Assistant Nurse/Nurse Practitioner | 1/27/2011 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
Tejasinha Sivalingam v. Dept. of Labor (Hunger Mountain Cooperative, Inc., Employer) | 1/27/2011 | Employment Security Board | n/a | Affirmed.
In re L.B. and M.B., Juveniles | 1/27/2011 | Lamoille Unit, Family Division | Dean B. Pineles | Affirmed.
In re A.S., Juvenile | 1/27/2011 | Rutland Unit, Family Division | Nancy Corsones | Affirmed.
In re T.H., Juvenile | 1/27/2011 | Addison Unit, Family Division | Cortland Corsones | Affirmed.
State v. Kaseen Smith | 1/27/2011 | Chittenden Unit, Criminal Division | Geoffrey W. Crawford | Affirmed.
Judith Pizzagalli v. Town of Shelburne | 1/27/2011 | Property Valuation and Review Division | n/a | Affirmed.
State v. Frederick Hunter | 1/27/2011 | Chittenden Unit, Civil Division | Michael S. Kupersmith | Affirmed.
State v. Aaron Todd | 1/27/2011 | Rutland Unit, Criminal Division | Thomas A. Zonay | Affirmed.
State v. Todd Maddox, Sr. | 1/27/2011 | Bennington Unit, Criminal Division | David Suntag | Affirmed.
State v. Robert Gilman | 1/27/2011 | Washington Unit, Criminal Division | Brian J. Grearson | Reversed and remanded.
State v. Michael Witter | 1/27/2011 | Chittenden Unit, Criminal Division | Michael S. Kupersmih | Affirmed.
State v. Charles Chandler | 1/27/2011 | Windham Unit, Criminal Division | Karen R. Carroll | Affirmed.
Month of Decision: 03 | March
Jodi Milko v. James Milko | 3/3/2011 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
State v. Ronald McGivern | 3/4/2011 | Windham Unit, Criminal Division | Karen R. Carroll | Affirmed.
State v. Richard Harrington | 3/4/2011 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
Amy Stevens v. Vito Russo | 3/4/2011 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
Amon Sylvester v. Andrew Pallito, Comm., Dept. of Corrections | 3/4/2011 | Orleans Unit, Civil Division | Edward J. Cashman | Affirmed.
Katheryn "Kitty" Garcia v. Alpine Glen Farm/Broadspire | 3/4/2011 | Chittenden Unit, Civil Division | Helen M. Toor | Affirmed.
In re Edmund Bills | 3/4/2011 | Human Services Board | n/a | Reversed and remanded.
Robert Merriam v. Department of Labor | 3/4/2011 | Employment Security Board | n/a | Affirmed.
Lee Chapman, Sr. v. Robert Spaulding Enterprises, Inc., et al. | 3/4/2011 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
State v. Vincent Brown | 3/4/2011 | Chittenden Unit, Criminal Division | Linda Levitt | Affirmed.
Tyrone Byrd v. Andrew Pallito, Bob E. Arkley, Jonathan Bruce and Dept. of Corrections | 3/4/2011 | Washington Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Timothy Clodgo v. Dept. of Labor (Petropreneurs, LLC, Employer) | 3/4/2011 | Employment Security Board | n/a | Affirmed.
In re S.M. and A.M., Juveniles | 3/4/2011 | Orange Unit, Family Division | Thomas J. Devine | Affirmed.
In re M.C., Juvenile | 3/4/2011 | Bennington Unit, Family Division | Karen R. Carroll | Affirmed.
State v. Charles Madigan | 3/25/2011 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
Month of Decision: 04 | April
In re Marvin Waldman | 4/21/2011 | Human Services Board | n/a | Affirmed.
State v. Andrew Jimmo | 4/21/2011 | Chittenden Unit, Criminal Division | Michael S. Kupersmith | Affirmed.
State v. Wallace Nolen | 4/21/2011 | Washington Unit, Criminal Division | Brian J. Grearson | Affirmed.
State v. Cameron Wood | 4/21/2011 | Franklin Unit, Criminal Division | A. Gregory Rainville | The court's denial of defendant's motion to supress is reversed, and the court's order granting judgment to the State is vacated.
State v. Adam Brouillard | 4/21/2011 | Addision Unit, Criminal Division | Cortland Corsones | Affirmed.
State v. Corey Price | 4/21/2011 | Chittenden Unit, Criminal Division | Linda Levitt | Affirmed.
State v. Terry Doe | 4/21/2011 | Chittenden Unit, Criminal Division | Linda Levitt | Affirmed.
Kelly VanZile v. Department of Labor | 4/21/2011 | Employment Security Board | n/a | Reversed and remanded for further proceedings consistent with the views expressed herein.
State v. Brittain Shorter | 4/21/2011 | Chittenden Unit, Criminal Division | M. Patricia Zimmerman | Affirmed.
Valerie Gadreault v. Raymond Gadreault | 4/21/2011 | Washington Unit, Family Division | Brian J. Grearson | Affirmed.
John Burgess and Virginia Burgess v. Lamoille Housing Project & Town of Morristown | 4/21/2011 | Lamoille Unit, Civil Division | Dennis R. Pearson | Affirmed.
In re Scott Beyor | 4/21/2011 | Rutland Unit, Civil Division | Mary Miles Teachout | Affirmed.
In re K.G. and A.G., Juveniles | 4/21/2011 | Franklin Unit, Family Division | Mark J. Keller | Affirmed.
Thomas Keefe v. Jessica Howard | 4/21/2011 | Bennington Unit, Family Division | Karen R. Carroll | Affirmed.
In re T.A., D.A., A.A., A.A., B.A. and A.A., Juveniles | 4/21/2011 | Chittenden Unit, Family Division | Edward J. Cashman | Affirmed.
In re B.M. | 4/21/2011 | Washington Unit, Family Division | Stephen B. Martin | Affirmed.
State v. Donald O'Dell, Jr. | 4/21/2011 | Bennington Unit, Criminal Division | David Suntag | Affirmed.
Month of Decision: 05 | May
State v. Christopher Crowningshield | 5/25/2011 | Addison Unit, Criminal Division | Nancy Corsones | Defendant is permitted to have contact with Amy Crowningshield through third parties for the limited purpose of facilitating contact with R.C.; the remaining conditions are affirmed.
Month of Decision: 06 | June
Lee Boisvert v. Jacques Boisvert | 6/7/2011 | Chittenden Unit, Family Division | M. Patricia Zimmerman | Affirmed.
Connie Holmes v. Victor Allen Holmes | 6/14/2011 | Washington Unit, Family Division | Brian J. Grearson | Affirmed.
State v. Peter Mertens | 6/1/2011 | Franklin Unit, Criminal Division | A. Gregory Rainville | Affirmed.
Laura Love Vollbrecht v. Kris Vollbrecht | 6/1/2001 | Chittenden Unit, Family Division | Matthew I. Katz | Affirmed.
State v. Jessica Stone | 6/1/2011 | Rutland Unit, Criminal Division | Thomas A. Zonay | Affirmed.
State v. Sulaiman Jadallah | 6/1/2011 | Franklin Unit, Criminal Division | Mark J. Keller | Affirmed.
Catherine Heller v. Bast & Rood Architects and Kemper Insurance | 6/1/2011 | Department of Labor | n/a | Affirmed.
Donald Sinex v. Christopher Wurster | 6/1/2011 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
In re W.M. | 6/1/2011 | Human Services Board | n/a | Reversed and remanded.
Clinton Bedell v. State | 6/1/2011 | Washington Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
Luke Perry, Sr. v. Julie Perry | 6/1/2011 | Orleans Unit, Family Division | Edward J. Cashman | Affirmed.
In re C.G., Juvenile | 6/1/2011 | Windham Unit, Family Division | Thomas A. Zonay | Affirmed.
Hanson Homestead, Inc. v. Chad Woodard and Jaska Hill | 6/1/2011 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
Robert Winchell v. Robert Hofmann | 6/1/2011 | Orleans Unit, Civil Division | Walter M. Morris, Jr. | Affirmed.
State v. Taylor James | 6/1/2011 | Windsor Unit, Criminal Division | Theresa S. DiMauro | Affirmed.
Month of Decision: 07 | July
Gordon Campbell, Jr. v. Ellen McWard, Brian Kearns, et al. | 7/7/2011 | Windsor Unit, Civil Division | Harold E. Eaton, Jr. | Affirmed.
Lisa Force v. Erik Schmitt | 7/7/2011 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
State v. Cynthia Cameron | 7/7/2011 | Rutland Unit, Criminal Division | Thomas A. Zonay | Affirmed.
Jane Krochmalny and Office of Child Support v. Wayne Mills | 7/7/2011 | Windham Unit, Family Division | Katherine A. Hayes | Affirmed.
Melody Corcoran v. James Walters, Jr. | 7/7/2011 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
State v. Gregory Penn a/k/a David Smith | 7/7/2011 | Bennington Unit, Criminal Division | David Suntag | Affirmed.
In re Chris Khamnei | 7/7/2011 | Chittenden Unit, Civil Division | Helen M. Toor | Affirmed.
George Brott v. Department of Labor (J.A. McDonald, Inc.) | 7/7/2011 | Employment Security Board | n/a | Reversed and remanded.
Edward Kadunc v. Dept of Labor (East Burke School, Employer) | 7/11/2011 | Employment Security Board | n/a | The Board's decision is reversed, and the request for attorney's fees is denied.
Marion Sibley v. Dept of Labor (Eric Seyferth, M.D., Employer) | 7/7/2011 | Employment Security Board | n/a | Affirmed.
In re D.L.S., Juvenile | 7/7/2011 | Chittenden Unit, Family Division | Edward J. Cashman | Affirmed.
In re Keith Russell Judd | 7/7/2011 | Washington Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
In re Bowen Conditional Use Application After Remand | 7/7/2011 | Environmental Division | Merideth Wright | Affirmed.
State v. James Eastman | 7/28/2011 | Windsor Unit, Criminal Division | M. Patricia Zimmerman | Affirmed.
Month of Decision: 08 | August
John Muir v. Andre Thibault, Matthew Gonyo and Dept of Liquor Control | 8/31/2011 | Franklin Unit, Civil Division | Ben W. Joseph | Affirmed.
In re T.B. and S.B., Juveniles | 8/31/2011 | Windsor Unit, Family Division | William D. Cohen | Affirmed.
State v. Paul Mason | 8/31/2011 | Orleans Unit, Criminal Division | David A. Jenkins | Defendant's convictions for first-degree arson and burning to defraud an insurer are affirmed. The restitution matter is remanded to the criminal division.
State v. Richard Parah | 8/31/2011 | Franklin Unit, Criminal Division | Mark J. Keller | Affirmed.
In re Grievance of Lawrence Rosenberger | 8/31/2011 | Labor Relations Board | n/a | Affirmed.
Highridge Condominium Owners Assn. v. James Haff, et al. | 8/31/2011 | Rutland Unit, Civil Division | William D. Cohen | Affirmed.
Linda Mavilla v. Ralph Mavilla | 8/31/2011 | Bennington Unit, Family Division | Karen R. Carroll | Affirmed.
Melissa Dame v. Victor Hall | 8/31/2011 | Chittenden Unit, Family Division | Matthew I. Katz | Affirmed.
John Viskup v. Juliane Viskup | 8/31/2011 | Chittenden Unit, Family Division | M. Patricia Zimmerman | Affirmed.
In re M.A.V. | 8/15/2011 | Washington Unit, Civil Division | Brian J. Grearson | Dismissed.
Christine Lamothe v. Christopher LeBlanc | 8/31/2011 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
Month of Decision: 09 | September
Stephen Albrecht v. Town of Sunderland | 9/20/2011 | Property Value and Review Division | n/a | Reversed and remanded.
In re F.S., J.S., E.S., W.S., X.S. and K.S., Juveniles | 9/1/2011 | Chittenden Unit, Family Division | Edward J. Cashman/James R. Crucitti | Affirmed.
State v. Jason Gorman | 9/27/2011 | Franklin Unit, Criminal Division |  | The Court directs that defendant be held without bail.
State v. Janette Johnson | 9/21/2011 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
Frederick Bashara and Mary Bashara v. John Caton and Gloria Caton | 9/1/2011 | Washington Unit, Civil Division | Geoffrey W. Crawford | Judgment for plaintiffs is affirmed and the matter is remanded for a hearing on damages.
Francelle Bourgault-Zajac v. Jeffrey Zajac | 9/1/2011 | Windsor Unit, Family Division | Robert R. Bent | Affirmed.
Elizabeth Crawford v. Patricia Farrington and Honora Winery & Vineyard, Inc. | 9/1/2011 | Windham Unit, Civil Division | John P. Wesley | Affirmed.
Month of Decision: 11 | November
State v. Edward Everett | 11/9/2011 | Rutland Unit, Criminal Division | Thomas A. Zonay | Affirmed.
State v. Edward Johnson | 11/9/2011 | Washington Unit, Criminal Division | Brian J. Grearson | Affirmed.
Catamount/Riverside Co. v. The Kea Group, LLC | 11/9/2011 | Chittenden Unit, Civil Division | Helen M. Toor | Affirmed.
Town of Windham v. Sean Reese and Elizabeth Reese | 11/9/2011 | Windham Unit, Civil Division | John P. Wesley/David A. Howard | The superior court's judgement is affirmed in all respects, except that its January 12, 2011 order is amended to change the amount of the total fine from $10,610 to $10,460.
Anchor Foundations, Inc. v. R. Scott Ingalls d/b/a Ingalls & Ingalls Builders, Inc. and Casing Development, Inc. | 11/9/2011 | Franklin Unit, Civil Division | Ben W. Joseph/A. Gregory Rainville | Affirmed.
Milton Marasch v. Karissa Trepanier | 11/9/2011 | Chittenden Unit, Civil Division | Helen M. Toor | Reversed and remanded for a new trial on damages, if any.
State v. Douglas Bedell | 11/9/2011 | Orange Unit, Criminal Division | Harold E. Eaton, Jr. | Affirmed.
Brenda Shores v. Owen Jenkins | 11/9/2011 | Addison Unit, Civil Division | Nancy Corsones | Affirmed.
In re A.P. | 11/9/2011 | Human Services Board | n/a | Affirmed.
Deborah Clark v. Kevin Clark | 11/9/2011 | Lamoille Unit, Family Division | Dennis R. Pearson | Affirmed in part/Reversed in part.
Anne-Marie Matthews v. Thomas Matthews | 11/9/2011 | Chittenden Unit, Family Division | Matthew I. Katz | Affirmed.
Kalah Gharouni v. Lorenzo de Coninck | 11/9/2011 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
In re A.C., Juvenile | 11/9/2011 | Rutland Unit, Family Division | Cortland Corsones | Affirmed.
Mary Riby-Williams v. Emmanuel Riby Williams | 11/9/2011 | Washington Unit, Family Division | Howard E. Van Benthuysen | Affirmed.
Cheryl Letourneau and Christopher Letourneau v. Joseph M. Salomone, M.D. | 11/9/2011 | Franklin Unit, Civil Division | Ben W. Joseph | Affirmed.
David de Grasse v. Renee de Grasse | 11/9/2011 | Chittenden Unit, Family Division | Linda Levitt | That portion of the judgement providing for an annual automatic maintenance adjustment is reversed and the case is remanded for reconsideration of the issue. In all other respects, the judgement is affirmed.
In re A.R. and A.R., Juveniles | 11/9/2011 | Caledonia Unit, Family Division | Edward J. Cashman | Affirmed.
Month of Decision: 12 | December
James Hicks v. Robert Hofmann | 12/21/2011 | Washington Unit, Civil Division | Geoffrey W. Crawford | Affirmed.
State v. Nathan Berres | 12/21/2011 | Bennington Unit, Criminal Division | David A. Howard | Affirmed.
In re Dwight Tester | 12/21/2011 | Windham Unit, Civil Division | John P. Wesley | Affirmed.
John Demgard v. Keith Masseroni and KAM Services, Inc. | 12/22/2011 | Rutland Unit, Civil Division | Mary Miles Teachout | Affirmed.
State v. Matthew Trudeau | 12/21/2011 | Addison Unit, Criminal Division | Nancy Corsones | Affirmed.
State v. Mark Kriskov | 12/21/2011 | Rutland Unit, Criminal Division | Theresa S. DiMauro | Affirmed.
Jennifer Weiss v. Jonathan Weiss | 12/21/2011 | Lamoille Unit, Family Division | Dennis R. Pearson | Reversed and remanded.
Rodney Mayo v. Kevin Scott | 12/21/2011 | Chittenden Unit, Civil Division | Helen M. Toor | Affirmed.
State v. Robert Gilman | 12/21/2011 | Washington Unit, Criminal Division | Brian J. Grearson | Affirmed.
Randi May Steeves v. Helen Venheim | 12/21/2011 | Essex Unit, Civil Division | Robert P. Gerety, Jr. | Affirmed in part and remanded to the superior court with instructions consistent with this order.
Kellie Olio v. David Schurman | 12/21/2011 | Orleans Unit, Family Division | Robert R. Bent | Affirmed.
Josef Knoff v. Josef Knoff Illuminating | 12/21/2011 | Commissioner of Labor | n/a | Affirmed.
In re D. McD. | 12/21/2011 | Human Services Board | n/a | Affirmed.
Suzanne Davis v. Sean Davis | 12/21/2011 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
In re K.C., Juvenile | 12/21/2011 | Washington Unit, Family Division | Brian J. Grearson | Affirmed.
M.M. v. S.L. | 12/21/2011 | Chittenden Unit, Family Division | Linda Levitt | Affirmed.
State v. Rudolph Winston/State v. Cynthia Winston | 12/23/2011 | Windsor Unit, Criminal Division | M. Patricia Zimmerman | Condition 14 is supported by the proceedings below with respect to each child and its imposition is affirmed.
State v. Cynthia Winston/State v. Rudolph Winston | 12/23/2011 | Windsor Unit, Criminal Division | M. Patricia Zimmerman | Condition 14 is supported by the proceedings below with respect to each child and its imposition is affirmed.

| Sign In |  |